@@ -266,6 +266,7 @@ class Dataset(IterableDataset):
             random.shuffle(self.urls)
         self.sample = 0
         urls = self.urls
+        count = 0
         for epoch in range(self.epochs):
             for url in urls:
                 stream = None
@@ -273,6 +274,7 @@ class Dataset(IterableDataset):
                     files_of_archive = tardata(stream, handler=self.handler)
                     for fname, content in files_of_archive:
                         yield fname, content
+                        count += 1
                     maybe_collect()
 
     def __iter__(self):
@@ -325,3 +327,40 @@ class Dataset(IterableDataset):
         """Apply a list of functions to the tuple."""
         self.pipeline.append(filters.map_tuple(*args, handler=handler))
         return self
+
+    # TODO: add batching here
+
+
+class ChoppedDataset(IterableDataset):
+    """Change the actual and nominal length of an IterableDataset.
+
+    :param dataset: IterableDataset
+    :param length: declared length of the dataset
+    :param nominal: nominal length of dataset (if different from declared)
+
+    This will continuously iterate through the original dataset, but
+    impose new eopch boundaries at the given length/nominal.
+    This exists mainly as a workaround for the odd logic in DataLoader.
+    It is also useful for choosing smaller nominal epoch sizes with
+    very large datasets.
+
+    """
+    def __init__(self, dataset, length=None, nominal=None):
+        self.dataset = dataset
+        if length is None:
+            length = len(dataset)
+        self.length = length
+        self.nominal = self.length if nominal is None else nominal
+        self.source = iter(dataset)
+
+    def __len__(self):
+        return self.nominal
+
+    def __iter__(self):
+        for i in range(self.length):
+            try:
+                sample = next(self.source)
+            except StopIteration:
+                self.source = iter(self.dataset)
+                sample = next(self.source)
+            yield sample
